-- Function: 'removeUnwantedLogFields' is used to remove specific unwanted fields from log records for st (super-tenant) events.
-- Only meant to target non-platform logs.
function removeUnwantedLogFields(tag, timestamp, record)
    local cleaned_record = record

    cleaned_record["file"], cleaned_record["kubernetes"], cleaned_record["IKSlogs"], cleaned_record["node_name"], cleaned_record["meta"] = nil

    -- Remove "saveServiceCopy" key-value pair from the "message" field
    if cleaned_record.message then
        -- This gsub removes any occurrence of the "saveServiceCopy" key and its value from the JSON string
        cleaned_record.message = cleaned_record.message:gsub('"saveServiceCopy"%s*:%s*([^,}]+),?%s?', ''):gsub(',%s*}', '}')
        -- Ensure "saveServiceCopy" defaults to false as a boolean
        -- This prevents Mezmo from defaulting to true, ensuring logs are routed to STR only and not to STS
        -- Pattern '(%{)' captures the opening curly brace of the message key values insert in curly brackets
        -- Replacement '%1"saveServiceCopy": false, ' adds the "saveServiceCopy": false field as a boolean
        -- Second gsub removes trailing commas for valid formatting
        cleaned_record.message = cleaned_record.message:gsub('^%{', '%1"saveServiceCopy": false, '):gsub(',%s*}', '}')
    end

    -- Extracting the service name from the tag
    local _, _, service_name = tag:match('([^%.]+)%.([^%.]+)%.([^%.]+)')
    if service_name then
        -- Assigning the service name to the 'app' field in the record
        cleaned_record["app"] = service_name

        -- Add serviceName to the "message" field
        -- gsub replaces the closing json bracket with the field "serviceName" and concatinates it with the service name plus a new closing bracket
        if cleaned_record.message then
            cleaned_record.message = (cleaned_record.message:gsub('%}$', ',"serviceName": "') .. service_name .. '"}')
        end
    end

    return 1, timestamp, cleaned_record
end


-- Function: 'removeSTFields'
-- Description: This function removes specific fields, namely "saveServiceCopy", from log records.
-- It also renames the "logSourceCRN" field to "customerCRN" field. The "logSourceCRN" field was previously removed from ST fields
-- as it sent duplicate logs to customers using STS agents. Renaming the field allows CRN information to be sent to customers
-- for debugging and identification purposes without also sending duplicate logs.
-- These removals are targeted at events that meet the following criteria:
--   1. The 'saveServiceCopy' field value is true.
--   2. The events are routed to the service instance itself.
--   3. The events are not directed to the customer utilizing the respective service.
function removeSTFields(tag, timestamp, record)
    local cleaned_record = record

    -- Remove the "logSourceCRN" and "saveServiceCopy" key-value pair from within the "message" field
    if cleaned_record.message then
        cleaned_record.message = cleaned_record.message:gsub('"logSourceCRN"', '"customerCRN"')
        cleaned_record.message = cleaned_record.message:gsub('"saveServiceCopy"%s*:%s*([^,}]+),?%s?', ''):gsub(',%s*}', '}')
    end

    return 1, timestamp, cleaned_record
end
